DiscoveryComponent

Struct DiscoveryComponent 

pub struct DiscoveryComponent { /* private fields */ }
A lifecycle-managed discovery component.

Implements Component so it can be registered with the application component registry. On start it creates the provider via the factory, optionally registers the local service instance, and on stop it deregisters.

Implementations

Source

impl DiscoveryComponent

pub fn new(config: DiscoveryConfig) -> Self

Create a new discovery component from the given config.

pub fn with_registry( config: DiscoveryConfig, providers: DiscoveryRegistry, ) -> Self

Create a discovery component with an explicit provider registry.

pub fn registry(&self) -> Option<Arc<dyn Registry>>

Returns the registry, if the component has started.

pub fn discovery(&self) -> Option<Arc<dyn Discovery>>

Returns the discovery client, if the component has started.