pub struct DiscoveryComponent { /* private fields */ }Expand description
A lifecycle-managed discovery component.
Implements Component so it can be registered with the application component registry.
On start it creates the provider via the factory, optionally registers the local service instance,
and on stop it deregisters.
Implementations
Sourceimpl DiscoveryComponent
impl DiscoveryComponent
Sourcepub fn new(config: DiscoveryConfig) -> Self
pub fn new(config: DiscoveryConfig) -> Self
Create a new discovery component from the given config.
Sourcepub fn with_registry(
config: DiscoveryConfig,
providers: DiscoveryRegistry,
) -> Self
pub fn with_registry( config: DiscoveryConfig, providers: DiscoveryRegistry, ) -> Self
Create a discovery component with an explicit provider registry.